aboutsummaryrefslogtreecommitdiffstats
path: root/example/src/main/java/org/onap/msb/sdk/example/client/ExampleClient.java
diff options
context:
space:
mode:
Diffstat (limited to 'example/src/main/java/org/onap/msb/sdk/example/client/ExampleClient.java')
-rw-r--r--example/src/main/java/org/onap/msb/sdk/example/client/ExampleClient.java39
1 files changed, 19 insertions, 20 deletions
diff --git a/example/src/main/java/org/onap/msb/sdk/example/client/ExampleClient.java b/example/src/main/java/org/onap/msb/sdk/example/client/ExampleClient.java
index ac31836..4184b02 100644
--- a/example/src/main/java/org/onap/msb/sdk/example/client/ExampleClient.java
+++ b/example/src/main/java/org/onap/msb/sdk/example/client/ExampleClient.java
@@ -22,25 +22,24 @@ import org.onap.msb.sdk.httpclient.msb.MSBServiceClient;
public class ExampleClient {
- /**
- * @param args
- * @throws IOException
- */
- public static void main(String[] args) throws IOException {
- //For real use case, MSB IP and Port should come from configuration file instead of hard code here
- String MSB_IP="10.96.33.44";
- int MSB_Port=30081;
-
- MSBServiceClient msbClient = new MSBServiceClient(MSB_IP, MSB_Port);
-
- RestServiceCreater restServiceCreater =
- new RestServiceCreater(msbClient);
-
- AnimalServiceClient implProxy =
- restServiceCreater.createService(AnimalServiceClient.class);
-
- Animal animal = implProxy.queryAnimal("panda").execute().body();
- System.out.println("animal:" + animal);
- }
+ /**
+ * @param args
+ * @throws IOException
+ */
+ public static void main(String[] args) throws IOException {
+ // For real use case, MSB discovery IP and Port should come from configuration file instead
+ // of hard code here
+ String msb_discovery_ip = "127.0.0.1";
+ int msb_discovery_port = 10081;
+
+ MSBServiceClient msbClient = new MSBServiceClient(msb_discovery_ip, msb_discovery_port);
+
+ RestServiceCreater restServiceCreater = new RestServiceCreater(msbClient);
+
+ AnimalServiceClient implProxy = restServiceCreater.createService(AnimalServiceClient.class);
+
+ Animal animal = implProxy.queryAnimal("panda").execute().body();
+ System.out.println("animal:" + animal);
+ }
}